##  Applicable Use Cases
Applications are essential for all SAP LeanIX use cases. In the initial stage, we recommend building your inventory with applications, business capabilities, and organization fact sheets, as they are essential for generating any meaningful reports and insights.
